@@ -8,7 +8,7 @@ from ..models import TaskModel, WorkersModel
 
 class TaskView(BaseHandler):
     def get(self, task_id):
-        task = TaskModel.get_task_by_id(task_id)
+        task = TaskModel.get_task_by_id(self.application, task_id)
         if task is None:
             raise web.HTTPError(404, "Unknown task '%s'" % task_id)
 
@@ -17,6 +17,7 @@ class TaskView(BaseHandler):
 
 class TasksView(BaseHandler):
     def get(self):
+        app = self.application
         limit = self.get_argument('limit', None)
         worker = self.get_argument('worker', None)
         type = self.get_argument('type', None)
@@ -25,9 +26,9 @@ class TasksView(BaseHandler):
         worker = worker if worker != 'All' else None
         type = type if type != 'All' else None
 
-        tasks = TaskModel.iter_tasks(limit=limit, type=type, worker=worker)
-        workers = WorkersModel.get_workers()
-        seen_task_types = TaskModel.seen_task_types()
+        tasks = TaskModel.iter_tasks(app, limit=limit, type=type, worker=worker)
+        workers = WorkersModel.get_workers(app)
+        seen_task_types = TaskModel.seen_task_types(app)
 
         self.render("tasks.html", tasks=tasks,
                                   task_types=seen_task_types,
